@@ -16,9 +16,11 @@ class Account : public AbstractAccount
     Q_OBJECT
 
 public:
-    explicit Account(const QString &instance_uri, QNetworkAccessManager *nam, bool ignoreSslErrors = false, bool admin = true, QObject *parent = nullptr);
-    explicit Account(AccountConfig *settings, QNetworkAccessManager *nam, QObject *parent = nullptr);
+    explicit Account(const QString &instanceUri, QNetworkAccessManager *nam, QObject *parent = nullptr);
     ~Account() override;
+
+    bool successfullyAuthenticated() const override;
+
     void get(const QUrl &url,
              bool authenticated,
              QObject *parent,
@@ -55,7 +57,9 @@ public:
 
     void buildFromSettings() override;
 
-    void validateToken(bool newAccount = false) override;
+    void validateToken() override;
+
+    void setConfig(AccountConfig *config);
 
     Q_INVOKABLE void checkForFollowRequests() override;
 
@@ -63,18 +67,21 @@ public:
 
     Q_INVOKABLE void updatePushNotifications() override;
 
-    Q_INVOKABLE void registerTokodon(bool authCode);
+    /**
+     * @param useAuthCode Whether to use a manually typed code. Otherwise, uses the tokodon:// URI as a callback.
+     * @param addAdminScope Whether to request the admin scope.
+     */
+    Q_INVOKABLE void registerTokodon(bool useAuthCode, bool addAdminScope);
 
 private:
     void unsubscribePushNotifications();
     void subscribePushNotifications();
     QUrlQuery buildNotificationFormData();
 
-    bool m_ignoreSslErrors = false;
     QNetworkAccessManager *m_qnam;
     QMap<QString, QWebSocket *> m_websockets;
     bool m_hasPushSubscription = false;
-    bool m_requestingAdmin = false;
+    bool m_authenticated = false;
 
     // common parts for all HTTP request
     [[nodiscard]] QNetworkRequest makeRequest(const QUrl &url, bool authenticated) const;
